@@ -12,7 +12,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized once redefine );
 
-our $VERSION = '1.814';
+our $VERSION = '1.815';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -538,7 +538,8 @@ sub _dispatch {
    $SIG{QUIT} = \&_exit;
 
    {
-      local ($|, $!);
+      local $!;
+      # IO::Handle->autoflush not available in older Perl.
       select(( select(*STDERR), $| = 1 )[0]) if defined(fileno *STDERR);
       select(( select(*STDOUT), $| = 1 )[0]) if defined(fileno *STDOUT);
    }
@@ -682,7 +683,7 @@ MCE::Hobo - A threads-like parallelization module
 
 =head1 VERSION
 
-This document describes MCE::Hobo version 1.814
+This document describes MCE::Hobo version 1.815
 
 =head1 SYNOPSIS
 
