@@ -12,7 +12,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized numeric once );
 
-our $VERSION = '1.814';
+our $VERSION = '1.815';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -322,8 +322,8 @@ sub _share {
    my $self = bless [ $_id, $_class ], 'MCE::Shared::Object';
    $_ob2{ $_id } = $_freeze->($self);
 
-   if ($_class eq 'MCE::Shared::Cache') {
-      $_obj{ $_id }->_prealloc();
+   if ( my $_code = $_obj{ $_id }->can('_shared_init') ) {
+      $_code->($_obj{ $_id });
    }
 
    return $self;
@@ -2316,7 +2316,7 @@ MCE::Shared::Server - Server/Object packages for MCE::Shared
 
 =head1 VERSION
 
-This document describes MCE::Shared::Server version 1.814
+This document describes MCE::Shared::Server version 1.815
 
 =head1 DESCRIPTION
 
